@@ -4,8 +4,9 @@ OCO Source Materials
 (C) Copyright IBM Corporation 2019 All Rights Reserved
 The source code for this program is not published or otherwise divested of its trade secrets,
 irrespective of what has been deposited with the U.S. Copyright Office.
-Copyright (c) 2020 Red Hat, Inc.
+Copyright (c) 2020, 2021 Red Hat, Inc.
 */
+// Copyright Contributors to the Open Cluster Management project
 
 package config
 
@@ -13,7 +14,6 @@ import (
 	"flag"
 	"fmt"
 	"net"
-	"net/url"
 	"os"
 	"path/filepath"
 	"strconv"
@@ -22,23 +22,20 @@ import (
 	"github.com/tkanos/gonfig"
 	"k8s.io/client-go/rest"
 	"k8s.io/client-go/tools/clientcmd"
-	"k8s.io/helm/pkg/tlsutil"
 )
 
 // Out of box defaults
 const (
-	COLLECTOR_API_VERSION      = "2.1.0"
+	COLLECTOR_API_VERSION      = "2.3.0"
 	DEFAULT_AGGREGATOR_URL     = "https://localhost:3010" // this will be deprecated in the future
 	DEFAULT_AGGREGATOR_HOST    = "https://localhost"
 	DEFAULT_AGGREGATOR_PORT    = "3010"
 	DEFAULT_CLUSTER_NAME       = "local-cluster"
-	DEFAULT_HEARTBEAT_MS       = 60000  // 1 min
+	DEFAULT_HEARTBEAT_MS       = 300000 // 5 min
 	DEFAULT_MAX_BACKOFF_MS     = 600000 // 10 min
-	DEFAULT_REDISCOVER_RATE_MS = 60000  // 1 min
+	DEFAULT_REDISCOVER_RATE_MS = 120000 // 2 min
 	DEFAULT_REPORT_RATE_MS     = 5000   // 5 seconds
 	DEFAULT_RUNTIME_MODE       = "production"
-	DEFAULT_TILLER_HOST        = "tiller-deploy.kube-system" // Deprecated in 2.1
-	DEFAULT_TILLER_PORT        = "44134"                     // Deprecated in 2.1
 )
 
 // Configuration options for the search-collector.
@@ -58,14 +55,16 @@ type Config struct {
 	RediscoverRateMS     int    `env:"REDISCOVER_RATE_MS"` // Interval(ms) to poll for changes to CRDs
 	ReportRateMS         int    `env:"REPORT_RATE_MS"`     // Interval(ms) to send changes to the aggregator
 	RuntimeMode          string `env:"RUNTIME_MODE"`       // Running mode (development or production)
-	TillerOpts           tlsutil.Options
-	TillerURL            string `env:"TILLER_URL"` // Deprecated: URL host path of the tiller server
 }
 
 var Cfg = Config{}
 var FilePath = flag.String("c", "./config.json", "Collector configuration file") // ./config.json is the default
 
 func init() {
+	InitConfig()
+}
+
+func InitConfig() {
 	// Load default config from ./config.json.
 	// These can be overridden in the next step if environment variables are set.
 	if _, err := os.Stat(filepath.Join(".", "config.json")); !os.IsNotExist(err) {
@@ -109,35 +108,6 @@ func init() {
 	}
 	setDefault(&Cfg.KubeConfig, "KUBECONFIG", defaultKubePath)
 
-	defaultTillerUrl := net.JoinHostPort(DEFAULT_TILLER_HOST, DEFAULT_TILLER_PORT)
-	if Cfg.RuntimeMode == "development" {
-		// find an external ip address to connect to tiller for dev env
-		// warning: this assumes the proxy node has same ip as master
-		// only use this config to make development life easier
-		client, _ := clientcmd.BuildConfigFromFlags("", Cfg.KubeConfig)
-		if client != nil && client.Host != "" {
-			u, _ := url.Parse(client.Host)
-			defaultTillerUrl = net.JoinHostPort(u.Hostname(), "31514")
-		}
-
-		glog.Warning("Using insecure HTTPS connection to tiller.")
-		Cfg.TillerOpts = tlsutil.Options{
-			CertFile:           filepath.Join(os.Getenv("HOME"), ".helm", "cert.pem"),
-			CaCertFile:         filepath.Join(os.Getenv("HOME"), ".helm", "ca.pem"),
-			KeyFile:            filepath.Join(os.Getenv("HOME"), ".helm", "key.pem"),
-			InsecureSkipVerify: true,
-		}
-	} else {
-		Cfg.TillerOpts = tlsutil.Options{
-			CertFile:           filepath.Join("/helmcerts", "tls.crt"),
-			CaCertFile:         filepath.Join("/helmcerts", "ca.crt"),
-			KeyFile:            filepath.Join("/helmcerts", "tls.key"),
-			InsecureSkipVerify: false,
-		}
-	}
-
-	setDefault(&Cfg.TillerURL, "TILLER_URL", defaultTillerUrl)
-
 	// Special logic for setting DEPLOYED_IN_HUB with default to false
 	if val := os.Getenv("DEPLOYED_IN_HUB"); val != "" {
 		glog.Infof("Using DEPLOYED_IN_HUB from environment: %s", val)
